import { IEvent, IView, IAnalyticsConfiguration, IAction, IUser } from './analytics/DataModels';
/**
 * Engagement Insights class that is used to send events.
 */
export default class Analytics {
    private _applicationInsightsCore;
    private _postChannel;
    private _properties;
    private _configuration;
    private _isInitialized;
    private _lastView;
    private _lastViewTime;
    private _previousView;
    private _storageDisabled;
    private _storageManager;
    private _sessionManager;
    private _autoCollector;
    private _invalidSignalPrefix;
    private _invalidSignalLongPrefix;
    private _user;
    private _setUserBeforeInitialize;
    /**
     * Initializes the Analytics class according to the passed configuration. It will send autocollected events if the passed
     * configuration specifies it.
     * @param configuration the configuration used to initialize the Analytics class
     */
    initialize(configuration: IAnalyticsConfiguration): void;
    /**
     * Tracks a custom event to be sent to Engagement Insights.
     * @param event event to be sent
     */
    trackEvent(event: IEvent): void;
    /**
     * Tracks a view event to be sent to Engagement Insights.
     * @param view view event to be sent
     */
    trackView(view: IView): void;
    /**
     * Tracks an action event to be sent to Engagement Insights.
     * @param action action event to be sent
     * @param properties custom properties that are part of this event as defined by the emitter.
     */
    trackAction(action: IAction, properties?: {
        [key: string]: string | number | boolean;
    }): void;
    /**
     * Teardown the SDK, and flushes all events currenlty in the queue.
     * After this method the SDK can be re-initialized with a new configuration.
     */
    teardown(): void;
    /**
     * Set custom property to be sent with every event.
     * @param name name of property
     * @param value value for the property
     */
    setProperty(name: string, value: string | number | boolean | Date): void;
    /**
     * Set user details to be sent with every event. Update UserMapping depending on whether the SDK is initialized or not
     * @param user user details
     */
    setUser(user: IUser): void;
    private _trackEvent;
    private _sanitizeProperties;
    private _isValidKey;
    private _addScreenInfo;
    private _addViewInfo;
    private _addAutocollectableFieldsToView;
    private _updateUserMapping;
    private _deleteOldestUserMapping;
}
