import { IExtendedTelemetryItem } from '@microsoft/1ds-core-js';
import StorageManager from './StorageManager';
/**
 * Class to manage session
 */
export default class SessionManager {
    private _session;
    private _storageManager;
    /**
     * Creates an instance of the session manager.
     * @param storageManager storage manager to store session details.
     */
    constructor(storageManager: StorageManager);
    /**
     * Process the session state based on the recieved event and add the session fields.
     * @param event Event to add session fields to.
     * @param userCookieExists Indicates if the user cookie was created.
     */
    _processEvent(event: IExtendedTelemetryItem, userCookieCreated: boolean, isHit: boolean): void;
    /**
     * Returns true if a session is active. False otherwise.
     * @param time The event time for the signal that is used to extend or start the session.
     * @param reload Set to true, if we should reload from storage before checking. For view events this should be true.
     */
    _isSessionActive(time: number, reload?: boolean): boolean;
    /**
     * Extends an ongoing session or starts a new one.
     * @param time The event time for the signal that is used to extend or start the session.
     * @param event The event that is being processed.
     * @param userCookieCreated Indicates if the user user cookie is created.
     */
    private _extendOrStartSession;
    private _parseSessionString;
    private _getSessionString;
    private _parseISOString;
}
