import * as sinon from 'sinon';
/// <reference path="external/qunit/index.d.ts" />
/** Defines a test case */
var TestCase = /** @class */ (function () {
    function TestCase() {
    }
    return TestCase;
}());
export { TestCase };
var TestClass = /** @class */ (function () {
    function TestClass(name) {
        /** Turns on/off sinon's fake implementation of XMLHttpRequest. On by default. */
        this.sandboxConfig = {};
        QUnit.module(name);
        this.sandboxConfig.injectInto = null;
        this.sandboxConfig.properties = ['spy', 'stub', 'mock', 'sandbox'];
    }
    /** Method called before the start of each test method */
    // tslint:disable-next-line:no-empty
    TestClass.prototype.testInitialize = function () { };
    /** Method called after each test method has completed */
    // tslint:disable-next-line:no-empty
    TestClass.prototype.testCleanup = function () { };
    /** Method in which test class intances should call this.testCase(...) to register each of this suite's tests. */
    // tslint:disable-next-line:no-empty
    TestClass.prototype.registerTests = function () { };
    /** Register an async Javascript unit testcase. */
    TestClass.prototype.testCaseAsync = function (testInfo) {
        var _this = this;
        if (!testInfo.name) {
            throw new Error('Must specify name in testInfo context in registerTestcase call');
        }
        if (isNaN(testInfo.stepDelay)) {
            throw new Error('Must specify \'stepDelay\' period between pre and post');
        }
        if (!testInfo.steps) {
            throw new Error('Must specify \'steps\' to take asynchronously');
        }
        // Create a wrapper around the test method so we can do test initilization and cleanup.
        var testMethod = function (assert) {
            var done = assert.async();
            // Save off the instance of the currently running suite.
            TestClass.currentTestClass = _this;
            // Run the test.
            try {
                _this._testStarting();
                var steps = testInfo.steps;
                var trigger = function () {
                    if (steps.length) {
                        var step = steps.shift();
                        // The callback which activates the next test step.
                        var nextTestStepTrigger = function () {
                            setTimeout(function () {
                                trigger();
                            }, testInfo.stepDelay);
                        };
                        // There 2 types of test steps - simple and polling.
                        // Upon completion of the simple test step the next test step will be called.
                        // In case of polling test step the next test step is passed to the polling test step, and
                        // it is responsibility of the polling test step to call the next test step.
                        try {
                            if (step[TestClass.isPollingStepFlag]) {
                                step.call(_this, nextTestStepTrigger);
                            }
                            else {
                                step.call(_this);
                                nextTestStepTrigger.call(_this);
                            }
                        }
                        catch (e) {
                            _this._testCompleted();
                            QUnit.assert.ok(false, e.toString());
                            // done is QUnit callback indicating the end of the test
                            done();
                            return;
                        }
                    }
                    else {
                        _this._testCompleted();
                        // done is QUnit callback indicating the end of the test
                        done();
                    }
                };
                trigger();
            }
            catch (ex) {
                QUnit.assert.ok(false, 'Unexpected Exception: ' + ex);
                _this._testCompleted(true);
                // done is QUnit callback indicating the end of the test
                done();
            }
        };
        // Register the test with QUnit
        QUnit.test(testInfo.name, testMethod);
    };
    /** Register a Javascript unit testcase. */
    TestClass.prototype.testCase = function (testInfo) {
        var _this = this;
        if (!testInfo.name) {
            throw new Error('Must specify name in testInfo context in registerTestcase call');
        }
        if (!testInfo.test) {
            throw new Error('Must specify \'test\' method in testInfo context in registerTestcase call');
        }
        // Create a wrapper around the test method so we can do test initilization and cleanup.
        var testMethod = function () {
            // Save off the instance of the currently running suite.
            TestClass.currentTestClass = _this;
            // Run the test.
            try {
                _this._testStarting();
                testInfo.test.call(_this);
                _this._testCompleted();
            }
            catch (ex) {
                QUnit.assert.ok(false, 'Unexpected Exception: ' + ex);
                _this._testCompleted(true);
            }
        };
        // Register the test with QUnit
        QUnit.test(testInfo.name, testMethod);
    };
    /** Called when the test is starting. */
    TestClass.prototype._testStarting = function () {
        this.sandbox = sinon.createSandbox(this.sandboxConfig);
        // Allow the derived class to perform test initialization.
        this.testInitialize();
    };
    /** Called when the test is completed. */
    TestClass.prototype._testCompleted = function (failed) {
        if (failed) {
            // Just cleanup the sandbox since the test has already failed.
            this.sandbox.restore();
        }
        else {
            // Verify the sandbox and restore.
            this.sandbox.verifyAndRestore();
        }
        this.testCleanup();
        // Clear the instance of the currently running suite.
        TestClass.currentTestClass = null;
    };
    TestClass.prototype.spy = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        return null;
    };
    TestClass.prototype.stub = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        return null;
    };
    /** Creates a mock for the provided object.Does not change the object, but returns a mock object to set expectations on the object's methods. */
    TestClass.prototype.mock = function (object) {
        return null;
    };
    /**** end: Sinon methods and properties ***/
    TestClass.prototype.setUserAgent = function (userAgent) {
        Object.defineProperty(window.navigator, 'userAgent', {
            configurable: true,
            get: function () {
                return userAgent;
            }
        });
    };
    TestClass.isPollingStepFlag = 'isPollingStep';
    return TestClass;
}());
export { TestClass };
//# sourceMappingURL=TestClass.js.map