import { __extends } from "tslib";
import { TestClass } from '../TestClass';
import * as sinon from 'sinon';
import Autocollector from '../../src/analytics/Autocollector';
import Analytics from '../../src/Analytics';
var AutocollectorTest = /** @class */ (function (_super) {
    __extends(AutocollectorTest, _super);
    function AutocollectorTest() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AutocollectorTest.prototype.testInitialize = function () {
        this._autoCollector = new Autocollector();
    };
    AutocollectorTest.prototype.registerTests = function () {
        var _this = this;
        this.testCase({
            name: 'Verify screen resoltion',
            test: function () {
                var doc = document;
                var win = window;
                var result = _this._autoCollector._getScreenResolution();
                QUnit.assert.equal(result.h, screen.height);
                QUnit.assert.equal(result.w, screen.width);
                QUnit.assert.equal(result.cd, screen.colorDepth);
                QUnit.assert.equal(result.vW, Math.max(doc.documentElement.clientWidth, win.innerWidth || 0));
                QUnit.assert.equal(result.vH, Math.max(doc.documentElement.clientHeight, win.innerHeight || 0));
                QUnit.assert.equal(result.sR, screen.height + 'X' + screen.width);
            }
        });
        this.testCase({
            name: 'Verify getReferrer',
            test: function () {
                var result = _this._autoCollector._getReferrer(document);
                QUnit.assert.equal(result.uri, document.referrer);
            }
        });
        this.testCase({
            name: 'Verify getPageNameFromPath',
            test: function () {
                var result = _this._autoCollector._getPageNameFromPath('/test/page/first.html');
                QUnit.assert.equal(result, 'first.html');
            }
        });
        this.testCase({
            name: 'Verify autocollecting views',
            test: function () {
                var analyticsStub = sinon.createStubInstance(Analytics);
                _this._autoCollector._autocollect(analyticsStub, {
                    view: false
                });
                QUnit.assert.notOk(analyticsStub.trackView.calledOnce);
                var viewSignal;
                analyticsStub.trackView.callsFake(function (arg) {
                    viewSignal = arg;
                });
                _this._autoCollector._autocollect(analyticsStub, {
                    view: true
                });
                QUnit.assert.ok(analyticsStub.trackView.calledOnce);
                QUnit.assert.equal(viewSignal.uri, location.href);
                QUnit.assert.equal(viewSignal.title, document.title.substring(0, 150));
                QUnit.assert.ok(viewSignal.referrer);
                QUnit.assert.ok(viewSignal.name);
            }
        });
        this.testCase({
            name: 'Verify autocollecting clicks adds eventlisteners',
            test: function () {
                var addSpy = sinon.spy(window, 'addEventListener');
                var removeSpy = sinon.spy(window, 'removeEventListener');
                var analyticsStub = sinon.createStubInstance(Analytics);
                _this._autoCollector._autocollect(analyticsStub, {
                    click: false
                });
                QUnit.assert.notOk(addSpy.calledOnce);
                _this._autoCollector._autocollect(analyticsStub, {
                    click: true
                });
                QUnit.assert.ok(addSpy.calledTwice);
                _this._autoCollector._removeAllListeners();
                QUnit.assert.ok(removeSpy.calledTwice);
                removeSpy.restore();
                addSpy.restore();
            }
        });
    };
    return AutocollectorTest;
}(TestClass));
export { AutocollectorTest };
//# sourceMappingURL=AutocollectorTest.js.map