import nodeResolve from "rollup-plugin-node-resolve";
import { uglify } from "rollup-plugin-uglify";
import commonjs from "rollup-plugin-commonjs";
import peerDepsExternal from "rollup-plugin-peer-deps-external";
import { es3Check, es3Poly, importCheck } from "@microsoft/applicationinsights-rollup-es3";

const version = require("./package.json").version;
const inputName = "dist-esm/src/Index.js";
const testInputName = "dist-esm/test/Index.js";
const outputName = "msei";
const banner = [
  "/*!",
  ` * Engagement Insights JS SDK, ${version}`,
  " * Copyright (c) Microsoft and contributors. All rights reserved.",
  " * Licensed under the ISC License.",
  " */"
].join("\n");

const browserRollupConfigFactory = (isProduction, isTestInput) => {
  var outputPath = `bundle/${outputName}-${version}.js`;
  var inputPath = `${inputName}`;
  if (isTestInput) {
    inputPath = `${testInputName}`;
    outputPath = `test/tests.js`;
  }
  const browserRollupConfig = {
    input: inputPath,
    output: {
      file: outputPath,
      banner: banner,
      format: "umd",
      name: "MSEI",
      extend: true,
      sourcemap: true
    },
    plugins: [
      peerDepsExternal(),
      nodeResolve({
        module: true,
        browser: false,
        preferBuiltins: false
      }),
      commonjs({
        include: "node_modules/**"
      })
    ]
  };

  if (!isTestInput) {
    browserRollupConfig.plugins.push(importCheck({ exclude: [ "Index" ] }));
    browserRollupConfig.plugins.push(es3Poly());
    browserRollupConfig.plugins.push(es3Check());
}

  if (isProduction) {
    browserRollupConfig.output.file = `bundle/${outputName}-${version}.min.js`;
    browserRollupConfig.plugins.push(
      uglify({
        mangle: {
          properties: {
            regex: /^_(?!_)/,
          }
        },
        output: {
          preamble: banner
        }
      })
    );
  }

  return browserRollupConfig;
};

export default [
  browserRollupConfigFactory(false),
  browserRollupConfigFactory(true),
  browserRollupConfigFactory(false, true)
];
